pub struct UnknownCode {
pub kind: &'static str,
pub value: String,
}Expand description
A code string that did not match any known variant of the requested
kind. Returned by FromStr implementations on the code enums.
Fields
kind: &'static strvalue: StringTrait Implementations
Sourceimpl Clone for UnknownCode
impl Clone for UnknownCode
Sourcefn clone(&self) -> UnknownCode
fn clone(&self) -> UnknownCode
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnknownCode
impl Debug for UnknownCode
Sourceimpl Display for UnknownCode
impl Display for UnknownCode
Sourceimpl Error for UnknownCode
impl Error for UnknownCode
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl From<UnknownCode> for ParseError
impl From<UnknownCode> for ParseError
Sourcefn from(source: UnknownCode) -> Self
fn from(source: UnknownCode) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for UnknownCode
impl PartialEq for UnknownCode
Sourcefn eq(&self, other: &UnknownCode) -> bool
fn eq(&self, other: &UnknownCode) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for UnknownCode
impl StructuralPartialEq for UnknownCode